
.. automodule:: bci_framework.kafka_scripts
   :members:
   :no-undoc-members:
   :no-show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   bci_framework.kafka_scripts.latency_synchronization_stimuli_marker
   bci_framework.kafka_scripts.latency_synchronization_visualization

Submodules
----------

.. toctree::
   :maxdepth: 4

   bci_framework.kafka_scripts.record
